class Note:
    
    def __init__(self, id = None, title = None, description = None, userId = None):
        self.Id = id
        self.Title = title
        self.Description = description
        self.UserId = userId